@@ -26,7 +26,7 @@ Palapeli::PuzzlePreview::PuzzlePreview(QWidget* parent)
 
 	setScene(new QGraphicsScene(this));
 	setParent(parent);
-	setWindowTitle(i18nc("Window title", "Preview of completed puzzle"));
+	setWindowTitle(i18nc("@title:window", "Preview of completed puzzle"));
 	setWindowFlags(Qt::Tool | Qt::WindowTitleHint);
 	setAttribute (Qt::WA_NoMousePropagation); // Accept all mouse events.
 	setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -61,7 +61,7 @@ void Palapeli::PuzzlePreview::loadImageFrom(const Palapeli::PuzzleMetadata& md)
 {
 	// Metadata is assumed to have been loaded by the caller.
 	setImage(md.image);
-	setWindowTitle(i18n("%1 - Preview", md.name));
+	setWindowTitle(i18nc("@title:window", "%1 - Preview", md.name));
 	// Set hover-zoom so that 3x3 pieces would be visible on a square grid.
 	m_hoverZoom = sqrt(md.pieceCount)/3.0;
 	if (m_hoverZoom < 1)
